@@ -59,10 +59,10 @@ rejectNode <- function(graph, node, verbose=FALSE) {
 	keepAlpha <- TRUE
 	
 	graph2 <- graph
-	if (all(TRUE == all.equal(edgesOut, rep(0, length(edgesOut))))) {
+	if (all(TRUE == all.equal(unname(edgesOut), rep(0, length(edgesOut))))) {
 		if (verbose) cat("Alpha is passed via epsilon-edges.\n")
 		for (to in nodes(graph)[nodes(graph)!=node]) {	
-			numberOfEpsilonEdges <- sum(TRUE == all.equal(edgesOut, rep(0, length(edgesOut))))
+			numberOfEpsilonEdges <- sum(TRUE == all.equal(unname(edgesOut), rep(0, length(edgesOut))))
 			if (existsEdge(graph, node, to)) {
 				nodeData(graph2, to, "alpha") <- nodeData(graph, to, "alpha")[[to]] + nodeData(graph, node, "alpha")[[node]] / numberOfEpsilonEdges
 				keepAlpha <- FALSE
